@@ -164,7 +164,7 @@ sub as_string
 {
 	my $self = shift;
 
-	my $prefix = $self->{prefix} || "DKIM-Signature:";
+	my $prefix = $self->{prefix} || $self->DEFAULT_PREFIX;
 
 	return $prefix . $self->SUPER::as_string;
 }
@@ -174,7 +174,7 @@ sub as_string_debug
 {
 	my $self = shift;
 
-	my $prefix = $self->{prefix} || "DKIM-Signature:";
+	my $prefix = $self->{prefix} || $self->DEFAULT_PREFIX;
 
 	return $prefix . join(";", map { ">" . $_->{raw} . "<" } @{$self->{tags}});
 }
@@ -289,8 +289,8 @@ sub canonicalization
 	my ($c1, $c2) = split(/\//, $c, 2);
 	if (not defined $c2)
 	{
-		# default body canonicalization depends on header canonicalization
-		$c2 = $c1 eq "nowsp" ? "nowsp" : "simple";
+		# default body canonicalization is "simple"
+		$c2 = "simple";
 	}
 
 	if (wantarray)
@@ -428,6 +428,11 @@ sub encode_qp
 	return $res;
 }
 
+sub DEFAULT_PREFIX
+{
+	return "DKIM-Signature:";
+}
+
 =head2 domain() - get or set the domain (d=) field
 
   my $d = $signature->domain;          # gets the domain value
@@ -807,7 +812,7 @@ sub prettify
 {
 	my $self = shift;
 	$self->wrap(
-		Start => length($self->{prefix} || "DKIM-Signature:"),
+		Start => length($self->{prefix} || $self->DEFAULT_PREFIX),
 		Tags => {
 			b => "b64",
 			bh => "b64",
@@ -829,7 +834,7 @@ sub prettify_safe
 {
 	my $self = shift;
 	$self->wrap(
-		Start => length($self->{prefix} || "DKIM-Signature:"),
+		Start => length($self->{prefix} || $self->DEFAULT_PREFIX),
 		Tags => {
 			b => "b64",
 			},
